==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Sukurti skaičiuoklę</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Sukurti naują skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Lygiuoti apačioje</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas apačioje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas per vidurį</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Lygiavimas kairėje</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas kairėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Lygiuoti dešinėje</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas dešinėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Lygiuoti viršuje</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas viršuje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Statmenasis lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Pasirinktų langelių statmenasis turinio lygiavimas per vidurį</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Eksportuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Eksportuoti skaičiuoklę į CSV failą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importuoti CSV failą į skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Sulieti langelius</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Sulieti pažymėtus langelius skaičiuoklėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Nustatyti kitą vardą</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Nustatyti kitą pažymėto langelio vardą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Skelti langelį</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Perskirti anksčiau sulietus langelius skaičiuoklėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Paryškintasis tekstas</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Nustatyti paryškintąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Pasvirasis tekstas</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Nustatyti pasvirąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Pabrauktasis tekstas</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Nustatyti pabrauktąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Keičiamas</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Langelio ypatybės</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Spalva</translation>
    </message>
    <message>
      <source>Text</source>
      <translation type="unfinished">Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fonas</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Lygiavimas</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Kairė</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Vidurys</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dešinys</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Iš viršaus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Apačioje</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stilius</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Paryškintas</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Pasvirasis</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Pabrauktas</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Ekrano vienetai</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Vienetų eilutė</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lternatyvus vardas</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Šio langelio kitas vardas</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Visi (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importuoti failą</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Eksportuoti failą</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Langelio turinys</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Rodyti skaičiuoklę</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Juoda</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Balta</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Raudona</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Tamsiai raudona</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Žalia</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Tamsiai žalia</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Mėlyna</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Tamsiai mėlyna</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Žydra</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Tamsi žalsvai mėlyna</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Rausvai raudona</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Tamsiai rausvai raudona</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Geltona</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Tamsiai geltona</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Pilka</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Tamsiai pilka</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Šviesiai pilka</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Keičiamas</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Turinys</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Be pavadinimo</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Įterpti eilutes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Šalinti eilutes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Įterpti stulpelius</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Šalinti stulpelius</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Ypatybės...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Sukurti skaičiuoklę</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Sukurti naują skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Lygiuoti apačioje</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas apačioje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas per vidurį</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Lygiavimas kairėje</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas kairėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Lygiuoti dešinėje</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas dešinėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Lygiuoti viršuje</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas viršuje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Statmenasis lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Center-align contents vertically of selected cells</source>
      <translation>Pasirinktų langelių statmenasis turinio lygiavimas per vidurį</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Eksportuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Eksportuoti skaičiuoklę į CSV failą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importuoti CSV failą į skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Sulieti langelius</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Sulieti pažymėtus langelius skaičiuoklėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Nustatyti kitą vardą</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Nustatyti kitą pažymėto langelio vardą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Skelti langelį</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Perskirti anksčiau sulietus langelius skaičiuoklėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Paryškintasis tekstas</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Nustatyti paryškintąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Pasvirasis tekstas</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Nustatyti pasvirąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Pabrauktasis tekstas</translation>
    </message>
    <message>
      <source>Set underline text in selected cells</source>
      <translation>Nustatyti pabrauktąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom</source>
      <translation>Pasirinktinė</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Langelio savybės</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Spalva</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekstas</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fonas</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Lygiavimas</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Kairė</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Vidurys</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dešinys</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Iš viršaus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Apačioje</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stilius</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Paryškintas</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Pasvirasis</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Pabrauktas</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Ekrano vienetai</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Vienetų eilutė</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lternatyvus vardas</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Šio langelio kitas vardas</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Visi (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importuoti failą</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Eksportuoti failą</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Langelio turinys</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Rodyti skaičiuoklę</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Juoda</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Balta</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Raudona</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Tamsiai raudona</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Žalia</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Tamsiai žalia</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Mėlyna</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Tamsiai mėlyna</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Žydra</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Tamsi žalsvai mėlyna</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Rausvai raudona</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Tamsiai rausvai raudona</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Geltona</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Tamsiai geltona</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Pilka</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Tamsiai pilka</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Šviesiai pilka</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Pasirinktinė</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Turinys</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Be pavadinimo</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Įterpti eilutes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Šalinti eilutes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Įterpti stulpelius</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Šalinti stulpelius</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Savybės...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
  </context>
</TS>
